fetch_chrome_history: fetch Chrome browser history

Description Usage

Description

this function will fetch all your Google Chrome browser history and store it in a 'chrome_history' psdlow style class with special methods in multiple funcitons defined within this package. Currently, it only reads data from <insert what it does here> while importing that data into a structured class.

Usage

1

sempervent/psdlow documentation built on May 26, 2019, 4:30 a.m.