this function will fetch all your Google Chrome browser history and store it in a 'chrome_history' psdlow style class with special methods in multiple funcitons defined within this package. Currently, it only reads data from <insert what it does here> while importing that data into a structured class.
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.